@@ -20,15 +20,15 @@ class FileLogReaderAdmin(admin.ModelAdmin):
 
     def changelist_view(self, request, extra_context=None):
         filename = request.GET.get('file_name', settings.LOG_READER_DEFAULT_FILE)
-
-        is_valid, file_contents = read_file_lines(
-            file_name=filename)
+        is_valid, file_contents = read_file_lines(file_name=filename)
+        if not is_valid:
+            self.message_user(request, file_contents, level=messages.ERROR)
         log_files = get_log_files(settings.LOG_READER_DIR_PATH)
 
         context = dict(
             self.admin_site.each_context(request),
             log_files=log_files,
-            file_contents=file_contents,
+            file_contents=file_contents if is_valid else [],
             file_name=filename,
             django_version=django.get_version()
         )
